pub enum ConnectionAuthError {
IncompatibleVersion,
InvalidSecret,
ServerError,
Other(String),
}Expand description
Authentication error types returned by the server during authentication.
Variants
IncompatibleVersion
Client protocol version is not supported by the server.
InvalidSecret
Authentication secret is invalid or incorrect.
ServerError
Internal server error during authentication processing.
Other(String)
Other error