Functions
- ombrac_
server_ get_ version - Returns the version of the ombrac-server library.
- ombrac_
server_ service_ shutdown - Shuts down the running service and releases all associated resources.
- ombrac_
server_ ⚠service_ startup - Initializes and starts the service with a given JSON configuration.
- ombrac_
server_ ⚠set_ log_ callback - Initializes the logging system to use a C-style callback for log messages.