#[unsafe(no_mangle)]pub unsafe extern "C" fn ombrac_server_set_log_callback(
callback: *const LogCallback,
)Expand description
Initializes the logging system to use a C-style callback for log messages.
This function must be called before ombrac_server_service_startup if you wish to
receive logs in a C-compatible way. It sets up a global logger that will
forward all log records to the provided callback function.
Arguments
callback- A function pointer of typeLogCallback. See the definition ofLogCallbackfor the expected signature and log level mappings.
Safety
The provided callback function pointer must be valid and remain valid for
the lifetime of the program. If a null pointer is passed, logging will be
disabled.