#[unsafe(no_mangle)]pub extern "C" fn ombrac_server_get_version() -> *const c_charExpand description
Returns the version of the ombrac-server library.
The returned string is a null-terminated UTF-8 string. The memory for this string is managed by the library and should not be freed by the caller.